@@ -1,6 +1,6 @@
 from enum import Enum
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence
 from warnings import warn
 
 import black
@@ -19,17 +19,42 @@ class PythonVersion(Enum):
         return self.value >= self.PY_38.value  # type: ignore
 
 
-BLACK_PYTHON_VERSION: Dict[PythonVersion, black.TargetVersion] = {
-    v: getattr(black.TargetVersion, f'PY{v.name.split("_")[-1]}')
-    for v in PythonVersion
-    if hasattr(black.TargetVersion, f'PY{v.name.split("_")[-1]}')
-}
+if TYPE_CHECKING:
+
+    class _TargetVersion(Enum):
+        ...
+
+    BLACK_PYTHON_VERSION: Dict[PythonVersion, _TargetVersion]
+else:
+    BLACK_PYTHON_VERSION: Dict[PythonVersion, black.TargetVersion] = {
+        v: getattr(black.TargetVersion, f'PY{v.name.split("_")[-1]}')
+        for v in PythonVersion
+        if hasattr(black.TargetVersion, f'PY{v.name.split("_")[-1]}')
+    }
 
 
 def is_supported_in_black(python_version: PythonVersion) -> bool:  # pragma: no cover
     return python_version in BLACK_PYTHON_VERSION
 
 
+def black_find_project_root(sources: Sequence[Path]) -> Path:
+    if TYPE_CHECKING:
+        from typing import Iterable, Tuple, Union
+
+        def _find_project_root(
+            srcs: Union[Sequence[str], Iterable[str]]
+        ) -> Union[Tuple[Path, str], Path]:
+            ...
+
+    else:
+        from black import find_project_root as _find_project_root
+    project_root = _find_project_root(tuple(str(s) for s in sources))
+    if isinstance(project_root, tuple):
+        return project_root[0]
+    else:
+        return project_root
+
+
 class CodeFormatter:
     def __init__(
         self,
@@ -40,7 +65,7 @@ class CodeFormatter:
         if not settings_path:
             settings_path = Path().resolve()
 
-        root = black.find_project_root((settings_path,))
+        root = black_find_project_root((settings_path,))
         path = root / "pyproject.toml"
         if path.is_file():
             value = str(path)
